 # ====================================================================
 # Copyright (c) 2004-2010 Open Source Applications Foundation.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the "Software"),
 # to deal in the Software without restriction, including without limitation
 # the rights to use, copy, modify, merge, publish, distribute, sublicense,
 # and/or sell copies of the Software, and to permit persons to whom the
 # Software is furnished to do so, subject to the following conditions: 
 #
 # The above copyright notice and this permission notice shall be included
 # in all copies or substantial portions of the Software. 
 #
 # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 # OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 # FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 # AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 # DEALINGS IN THE SOFTWARE.
 # ====================================================================

from _icu import *
from _icu import _install__doc__


_install__doc__(BreakIterator, '''
The BreakIterator class implements methods for finding the location of
boundaries in text.

BreakIterator is an abstract base class. Instances of BreakIterator maintain
a current position and scan over text returning the index of characters
where boundaries occur.

Line boundary analysis determines where a text string can be broken when
line-wrapping. The mechanism correctly handles punctuation and hyphenated
words.

Sentence boundary analysis allows selection with correct interpretation of
periods within numbers and abbreviations, and trailing punctuation marks
such as quotation marks and parentheses.

Word boundary analysis is used by search and replace functions, as well as
within text editing applications that allow the user to select words with a
double click. Word selection provides correct interpretation of punctuation
marks within and following words. Characters that are not part of a word,
such as symbols or punctuation marks, have word-breaks on both sides.

Character boundary analysis allows users to interact with characters as they
expect to, for example, when moving the cursor through a text
string. Character boundary analysis provides correct navigation of through
character strings, regardless of how the character is stored. For example,
an accented character might be stored as a base character and a diacritical
mark. What users consider to be a character can differ between languages.

The text boundary positions are found according to the rules described in
Unicode Standard Annex #29, Text Boundaries, and Unicode Standard Annex #14,
Line Breaking Properties. These are available at
http://www.unicode.org/reports/tr14/ and http://www.unicode.org/reports/tr29/.
''')

_install__doc__(BreakIterator.__init__, '''
BreakIterator is abstract. Use one of the class instantiators:
createWordInstance, createLineInstance, createCharacterInstance,
createSentenceInstance or createTitleInstance.
''')

_install__doc__(BreakIterator.getText, '''
Return the string over the text being analyzed.
''')

_install__doc__(BreakIterator.createLineInstance, '''
Returns an instance of a BreakIterator implementing line breaks. Line breaks
are logically possible line breaks, actual line breaks are usually
determined based on display width. LineBreak is useful for word wrapping
text.
''')




import os, sys

try:
    from setuptools import setup, Extension
except ImportError:
    from distutils.core import setup, Extension

VERSION = '1.9.8'

try:
    ICU_VERSION = os.environ['ICU_VERSION']
except:
    try:
        from subprocess import check_output
    except ImportError:
        from subprocess import Popen, PIPE
        def check_output(*popenargs):
            process = Popen(stdout=PIPE, *popenargs)
            output, ignore = process.communicate()
            retcode = process.poll()
            if retcode:
                raise RuntimeError((retcode, popenargs[0], output))
            return output
    try:
        ICU_VERSION = check_output(('icu-config', '--version')).strip()
        if sys.version_info >= (3,):
            ICU_VERSION = str(ICU_VERSION, 'ascii')
    except:
        raise RuntimeError('''
Please set the ICU_VERSION environment variable to the version of
ICU you have installed.
        ''')

print('''
Building PyICU %s for ICU %s
''' %(VERSION, ICU_VERSION))

INCLUDES = {
    'darwin': ['/usr/local/include'],
    'linux': [],
    'freebsd': ['/usr/local/include'],
    'win32': ['c:/icu/include'],
    'sunos5': [],
    'cygwin': [],
}

CFLAGS = {
    'darwin': ['-DPYICU_VER="%s"' %(VERSION), '-std=c++11'],
    'linux': ['-DPYICU_VER="%s"' %(VERSION), '-std=c++11'],
    'freebsd': ['-DPYICU_VER="%s"' %(VERSION), '-std=c++11'],
    'win32': ['/Zc:wchar_t', '/EHsc', '/DPYICU_VER=\\"%s\\"' %(VERSION)],
    'sunos5': ['-DPYICU_VER="%s"' %(VERSION), '-std=c++11'],
    'cygwin': ['-DPYICU_VER="%s"' %(VERSION), '-D_GNU_SOURCE=1', '-std=c++11'],
}

# added to CFLAGS when setup is invoked with --debug
DEBUG_CFLAGS = {
    'darwin': ['-O0', '-g', '-DDEBUG'],
    'linux': ['-O0', '-g', '-DDEBUG'],
    'freebsd': ['-O0', '-g', '-DDEBUG'],
    'win32': ['/Od', '/DDEBUG'],
    'sunos5': ['-DDEBUG'],
    'cygwin': ['-Og', '-g', '-DDEBUG'],
}

LFLAGS = {
    'darwin': ['-L/usr/local/lib'],
    'linux': [],
    'freebsd': ['-L/usr/local/lib'],
    'win32': ['/LIBPATH:c:/icu/lib'],
    'sunos5': [],
    'cygwin': [],
}

LIBRARIES = {
    'darwin': ['icui18n', 'icuuc', 'icudata'],
    'linux': ['icui18n', 'icuuc', 'icudata'],
    'freebsd': ['icui18n', 'icuuc', 'icudata'],
    'win32': ['icuin', 'icuuc', 'icudt'],
    'sunos5': ['icui18n', 'icuuc', 'icudata'],
    'cygwin': ['icui18n', 'icuuc', 'icudata'],
}

platform = sys.platform
if platform.startswith(('linux', 'gnu')):
    platform = 'linux'
elif platform.startswith('freebsd'):
    platform = 'freebsd'

if 'PYICU_INCLUDES' in os.environ:
    _includes = os.environ['PYICU_INCLUDES'].split(os.pathsep)
else:
    _includes = INCLUDES[platform]

if 'PYICU_CFLAGS' in os.environ:
    _cflags = os.environ['PYICU_CFLAGS'].split(os.pathsep)
else:
    _cflags = CFLAGS[platform]

if '--debug' in sys.argv:
    if 'PYICU_DEBUG_CFLAGS' in os.environ:
        _cflags += os.environ['PYICU_DEBUG_CFLAGS'].split(os.pathsep)
    else:
        _cflags += DEBUG_CFLAGS[platform]

if 'PYICU_LFLAGS' in os.environ:
    _lflags = os.environ['PYICU_LFLAGS'].split(os.pathsep)
else:
    _lflags = LFLAGS[platform]

if 'PYICU_LIBRARIES' in os.environ:
    _libraries = os.environ['PYICU_LIBRARIES'].split(os.pathsep)
elif ICU_VERSION < '58':
    _libraries = LIBRARIES[platform][:] + ['icule']
else:
    _libraries = LIBRARIES[platform]

if sys.version_info < (2, 4):
    def sorted(iterable, *args, **kwargs):
        iterable = list(iterable)
        iterable.sort(*args, **kwargs)
        return iterable


setup(name="PyICU",
      description='Python extension wrapping the ICU C++ API',
      long_description=open('README.md').read(),
      version=VERSION,
      test_suite="test",
      url='https://github.com/ovalhub/pyicu',
      author='Andi Vajda',
      author_email='github@ovaltofu.org',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Environment :: Console',
          'Intended Audience :: Developers',
          'License :: OSI Approved',
          'Operating System :: OS Independent',
          'Programming Language :: C++',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy',
          'Topic :: Software Development :: Localization',
          'Topic :: Software Development :: Internationalization'],
      ext_modules=[Extension('_icu',
                             [filename for filename in sorted(os.listdir(os.curdir))
                              if filename.endswith('.cpp')],
                             include_dirs=_includes,
                             extra_compile_args=_cflags,
                             extra_link_args=_lflags,
                             libraries=_libraries)],
      packages=['icu'],
      py_modules=['PyICU'],
      tests_require=['pytest', 'six'])
